-- ---------------------------------------------------------------------
-- Filename: core32x16.vhd 
-- Version: 1.0 
--
-- Date: April 2000                                            
--
-- Type: Configuration Specification
-- 
-- Description: Configuration for simulation only. One file per
-- 		    core, core32x16 in this example. All parameters
-- 		    are passed to the simulation model from this file.
-- ---------------------------------------------------------------------
-- XAPP 409                                 
-- Simulating a 3.1i Core generator VHDL Design
--                                           
-- Instantiate a Core Generator BRAM configured as 32x16 and a 
-- bi-directional bus for the DATA in/out. The design example 
-- used will have a CORE Generator macro down two levels in the 
-- hierarchy to illustrate how parameters are passed to the macros 
-- for functional simulation. The RAMB4_S16_S16 component is a 
-- 4096-bit dual-ported dedicated random access memory blocks with 
-- synchronous write capability. Each port is independent of the other 
-- while accessing the same set of 4096 memory cells. This example will 
-- not exercise the entire depth of the block RAM.
--  
-- Limited Warranty and Disclaimer. These designs are provided to you 
-- as is. Xilinx and its licensors make and you receive no warranties 
-- or conditions, express, implied, statutory or otherwise, and Xilinx 
-- specifically disclaims any implied warranties of merchantability, 
-- non-infringement, or fitness for a particular purpose. Xilinx does 
-- not warrant that the functions contained in these designs will meet 
-- your requirements, or that the operation of these designs will be 
-- uninterrupted or error free, or that defects in the Designs will be 
-- corrected. Furthermore, Xilinx does not warrant or make any 
-- representations regarding use or the results of the use of the 
-- designs in terms of correctness, accuracy, reliability, or otherwise. 
-- 
-- Limitation of Liability. In no event will Xilinx or its licensors be 
-- liable for any loss of data, lost profits, cost or procurement of 
-- substitute goods or services, or for any special, incidental, 
-- consequential, or indirect damages arising from the use or operation 
-- of the designs or accompanying documentation, however caused and on 
-- any theory of liability. This limitation will apply even if Xilinx 
-- has been advised of the possibility of such damage. This limitation 
-- shall apply not-withstanding the failure of the essential purpose of 
-- any limited remedies herein. 
--
-- ---------------------------------------------------------------------

-- synopsys translate_off
library IEEE;
use IEEE.std_logic_1164.all;

Library XilinxCoreLib;

entity core32x16 is
	port (
	addra: IN std_logic_VECTOR(4 downto 0);
	clka: IN std_logic;
	addrb: IN std_logic_VECTOR(4 downto 0);
	clkb: IN std_logic;
	dia: IN std_logic_VECTOR(15 downto 0);
	wea: IN std_logic;
	dib: IN std_logic_VECTOR(15 downto 0);
	web: IN std_logic;
	ena: IN std_logic;
	enb: IN std_logic;
	rsta: IN std_logic;
	rstb: IN std_logic;
	doa: OUT std_logic_VECTOR(15 downto 0);
	dob: OUT std_logic_VECTOR(15 downto 0));
end core32x16;

architecture core32x16_sim_arch of core32x16 is

BEGIN

	core32x16_SIM : entity XilinxCoreLib.C_MEM_DP_BLOCK_V1_0(behavioral)
		generic map(
			c_depth_b => 32,
			c_depth_a => 32,
			c_has_web => 1,
			c_has_wea => 1,
			c_has_dib => 1,
			c_has_dia => 1,
			c_clka_polarity => 1,
			c_web_polarity => 1,
			c_address_width_b => 5,
			c_address_width_a => 5,
			c_width_b => 16,
			c_width_a => 16,
			c_clkb_polarity => 1,
			c_ena_polarity => 1,
			c_rsta_polarity => 1,
			c_has_rstb => 1,
			c_has_rsta => 1,
			c_read_mif => 1,
			c_enb_polarity => 1,
			c_pipe_stages => 0,
			c_rstb_polarity => 1,
			c_has_enb => 1,
			c_has_ena => 1,
			c_mem_init_radix => 16,
			c_default_data => "0",
			c_mem_init_file => "./core32x16.mif",
			c_has_dob => 1,
			c_generate_mif => 1,
			c_has_doa => 1,
			c_wea_polarity => 1)
		port map (
			addra => addra,
			clka => clka,
			addrb => addrb,
			clkb => clkb,
			dia => dia,
			wea => wea,
			dib => dib,
			web => web,
			ena => ena,
			enb => enb,
			rsta => rsta,
			rstb => rstb,
			doa => doa,
			dob => dob);

end core32x16_sim_arch;
-- synopsys translate_on


