-- ---------------------------------------------------------------------
-- Filename: level2.vhd 
-- Version: 1.0 
--
-- Date: April 2000
--
-- Type: Configuration Specification
-- 
-- Description: 2nd level which instantiates the Core Generator core.
-- 		    top.vhd instantiates this file. Note that there is a 
--		    Configuration in a seperate VHDL file for each macro, 
--		    for simulation only.
-- ---------------------------------------------------------------------
-- XAPP 409                                 
-- Simulating a 3.1i Core generator VHDL Design
--                                           
-- Instantiate a Core Generator BRAM configured as 32x16 and a 
-- bi-directional bus for the DATA in/out. The design example 
-- used will have a CORE Generator macro down two levels in the 
-- hierarchy to illustrate how parameters are passed to the macros 
-- for functional simulation. The RAMB4_S16_S16 component is a 
-- 4096-bit dual-ported dedicated random access memory blocks with 
-- synchronous write capability. Each port is independent of the other 
-- while accessing the same set of 4096 memory cells. This example will 
-- not exercise the entire depth of the block RAM.
--                                                       
-- Limited Warranty and Disclaimer. These designs are provided to you 
-- as is. Xilinx and its licensors make and you receive no warranties 
-- or conditions, express, implied, statutory or otherwise, and Xilinx 
-- specifically disclaims any implied warranties of merchantability, 
-- non-infringement, or fitness for a particular purpose. Xilinx does 
-- not warrant that the functions contained in these designs will meet 
-- your requirements, or that the operation of these designs will be 
-- uninterrupted or error free, or that defects in the Designs will be 
-- corrected. Furthermore, Xilinx does not warrant or make any 
-- representations regarding use or the results of the use of the 
-- designs in terms of correctness, accuracy, reliability, or otherwise. 
-- 
-- Limitation of Liability. In no event will Xilinx or its licensors be 
-- liable for any loss of data, lost profits, cost or procurement of 
-- substitute goods or services, or for any special, incidental, 
-- consequential, or indirect damages arising from the use or operation 
-- of the designs or accompanying documentation, however caused and on 
-- any theory of liability. This limitation will apply even if Xilinx 
-- has been advised of the possibility of such damage. This limitation 
-- shall apply not-withstanding the failure of the essential purpose of 
-- any limited remedies herein. 
--
-- ---------------------------------------------------------------------

LIBRARY ieee;
use IEEE.std_logic_1164.all;

entity level2 is
    port(CLK         : in std_logic;
         WEA, WEB    : in std_logic;
         ADDRA, ADDRB: in std_logic_vector(4 downto 0);
         DIA, DIB : in std_logic_vector(15 downto 0);
         DOA, DOB : out std_logic_vector(15 downto 0));
end;

architecture struct of level2 is

  -- ---------------------------------------------
  -- declare the Core Generator BlockRAM component
  -- ---------------------------------------------
component core32x16
        port (
        addra: IN std_logic_VECTOR(4 downto 0);
        clka: IN std_logic;
        addrb: IN std_logic_VECTOR(4 downto 0);
        clkb: IN std_logic;
        dia : IN std_logic_VECTOR(15 downto 0);
        wea: IN std_logic;
        dib: IN std_logic_VECTOR(15 downto 0);
        web: IN std_logic;
        ena: IN std_logic;
        enb: IN std_logic;
        rsta: IN std_logic;
        rstb: IN std_logic;
        doa: OUT std_logic_VECTOR(15 downto 0);
        dob: OUT std_logic_VECTOR(15 downto 0));
end component;

  -- ---------------------------------
  -- Declare the signals in the design
  -- ---------------------------------
  SIGNAL ZERO : std_ulogic := '0';
  SIGNAL ONE : std_ulogic := '1';
  
begin

  -- -------------------------------------------------
  -- Instantiate the Core Generator BlockRAM component
  -- -------------------------------------------------
  U0 : core32x16 port map (
                        addra => ADDRA,
                        clka => CLK,
                        addrb => ADDRB,
                        clkb => CLK,
                        dia => DIA,
                        wea => WEA,
                        dib => DIB,
                        web => WEB,
                        ena => ONE,
                        enb => ONE,
                        rsta => ZERO,
                        rstb => ZERO,
                        doa => DOA,
                        dob => DOB);
end struct;
