-- ---------------------------------------------------------------------
-- Filename: top.vhd 
-- Version: 1.0 
-- 
-- Date: April 2000
--
-- Type: Top Level Configuration Declaration
-- 
-- Description: Top level design which instantiates level2.vhd.
--	          tb.vhd instantiates this file for stimulating
--              the design. Note that there is a configuration 
--		    only in the file cfg.vhd
-- ---------------------------------------------------------------------
-- XAPP 409                                 
-- Simulating a 3.1i Core generator VHDL Design
--                                           
-- Instantiate a Core Generator BRAM configured as 32x16 and a 
-- bi-directional bus for the DATA in/out. The design example 
-- used will have a CORE Generator macro down two levels in the 
-- hierarchy to illustrate how parameters are passed to the macros 
-- for functional simulation. The RAMB4_S16_S16 component is a 
-- 4096-bit dual-ported dedicated random access memory blocks with 
-- synchronous write capability. Each port is independent of the other 
-- while accessing the same set of 4096 memory cells. This example will 
-- not exercise the entire depth of the block RAM.
--  
-- Limited Warranty and Disclaimer. These designs are provided to you 
-- as is. Xilinx and its licensors make and you receive no warranties 
-- or conditions, express, implied, statutory or otherwise, and Xilinx 
-- specifically disclaims any implied warranties of merchantability, 
-- non-infringement, or fitness for a particular purpose. Xilinx does 
-- not warrant that the functions contained in these designs will meet 
-- your requirements, or that the operation of these designs will be 
-- uninterrupted or error free, or that defects in the Designs will be 
-- corrected. Furthermore, Xilinx does not warrant or make any 
-- representations regarding use or the results of the use of the 
-- designs in terms of correctness, accuracy, reliability, or otherwise. 
-- 
-- Limitation of Liability. In no event will Xilinx or its licensors be 
-- liable for any loss of data, lost profits, cost or procurement of 
-- substitute goods or services, or for any special, incidental, 
-- consequential, or indirect damages arising from the use or operation 
-- of the designs or accompanying documentation, however caused and on 
-- any theory of liability. This limitation will apply even if Xilinx 
-- has been advised of the possibility of such damage. This limitation 
-- shall apply not-withstanding the failure of the essential purpose of 
-- any limited remedies herein. 
--
-- ---------------------------------------------------------------------

LIBRARY ieee;
use IEEE.std_logic_1164.all;

entity top is
    port(CLK         : in std_logic;
         WEA, WEB    : in std_logic;
	   out_enable  : in std_logic;
         ADDRA, ADDRB: in std_logic_vector(4 downto 0);
         DATA_BUSA, DATA_BUSB : inout std_logic_vector(15 downto 0));
 end;

architecture struct of top is

  -- ---------------------------------------------
  -- declare the component for the 2nd level of hierarchy 
  -- ---------------------------------------------
component level2
    port(CLK         : in std_logic;
         WEA, WEB    : in std_logic;
         ADDRA, ADDRB: in std_logic_vector(4 downto 0);
         DIA, DIB : in std_logic_vector(15 downto 0);
         DOA, DOB : out std_logic_vector(15 downto 0));
end component;

signal DOA, DOB : std_logic_vector(15 downto 0);

begin

  -- -------------------------------------------------
  -- Instantiate the 2nd level of hierarchy which contains the Core Generator BlockRAM component
  -- -------------------------------------------------
  U0 : level2 port map (
                        addra => ADDRA,
                        clk => CLK,
                        addrb => ADDRB,
                        dia => DATA_BUSA,
                        wea => WEA,
                        dib => DATA_BUSB,
                        web => WEB,
                        DOA => DOA,
                        DOB => DOB);

  -- --------------------------
  -- Create the Tristate output
  -- --------------------------
  DATA_BUSA <= DOA when (out_enable = '1') else (others => 'Z');
  DATA_BUSB <= DOB when (out_enable = '1') else (others => 'Z');

end struct;


